@@ -1,7 +1,7 @@
 package Regexp::Pattern;
 
 our $DATE = '2018-03-24'; # DATE
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.2.2'; # VERSION
 
 use strict 'subs', 'vars';
 #use warnings;
@@ -133,7 +133,7 @@ Regexp::Pattern - Collection of regexp patterns
 
 =head1 VERSION
 
-This document describes version 0.2.1 of Regexp::Pattern (from Perl distribution Regexp-Pattern), released on 2018-03-24.
+This document describes version 0.2.2 of Regexp::Pattern (from Perl distribution Regexp-Pattern), released on 2018-03-24.
 
 =head1 SYNOPSIS
 
@@ -304,6 +304,50 @@ using a combination of these options: C<-has_tag> (only select patterns that
 have a specified tag), C<-lacks_tag> (only select patterns that do not have a
 specified tag).
 
+=head2 Recommendations for writing the regex patterns
+
+=over
+
+=item * Regexp pattern should be written as a C<qr//> literal
+
+Using a string literal is less desirable. That is:
+
+ pat => qr/foo[abc]+/,
+
+is preferable over:
+
+ pat => 'foo[abc]+',
+
+=item * Regexp pattern should not be anchored (unless really necessary)
+
+That is:
+
+ pat => qr/foo/,
+
+is preferable over:
+
+ pat => qr/^foo/, # or qr/foo$/, or qr/\Afoo\z/
+
+Adding anchors limits the reusability of the pattern. When composing pattern,
+user can add anchors herself if needed.
+
+When you define an anchored pattern, adding tag C<anchored> is recommended:
+
+ tags => ['anchored'],
+
+=item * Regexp pattern should not contain capture groups (unless really necessary)
+
+Adding capture groups limits the reusability of the pattern because it can
+affect the groups of the composed pattern. When composing pattern, user can add
+captures herself if needed.
+
+=item * Regexp pattern should not contain modifiers unless necessary
+
+An exception to this rule is the /x modifier which is usually recommended for
+longer patterns.
+
+=back
+
 =head1 FUNCTIONS
 
 =head2 re
